アメリカの地図を指定した州、指定した色で表示します。
事前に「pip install geopandas matplotlib」を実行してください。

Displays a map of the United States in the specified state and specified color.
Please run "pip install geopandas matplotlib in advance.